@@ -1,4 +1,4 @@
-from finvizfinance.util import webScrap, imageScrapFunction
+from finvizfinance.util import webScrap
 import pandas as pd
 import json
 
@@ -9,6 +9,7 @@ import json
 .. moduleauthor:: Tianning Li <ltianningli@gmail.com>
 """
 
+
 class Future:
     """Future
     Getting information from the finviz future page.
